Changelog
=========

0.2.0 (2016-04-05)
------------------

* Added context manager ``restarts`` and manager ``restart`` now gets
  only a function and returns a function like  to call code
  to be restarted.

0.1.0 (2016-03-29)
------------------

* First release on PyPI.
